@@ -2,7 +2,7 @@ package Catmandu::Store::ElasticSearch::CQL;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0505';
 
 use Catmandu::Util qw(require_package trim);
 use CQL::Parser;
@@ -301,7 +301,7 @@ sub _term_node {
 sub _text_node {
     my ($self, $qualifier, $term, @modifiers) = @_;
     if ($term =~ /[^\\][\*\?]/) { # TODO only works for single terms, mapping
-        return { query_string => { query => "$qualifier:$term" } };
+        return { query_string => { query => qq|$qualifier:"$term"| } };
     }
     # Unescape wildcards (when needed)...
     $term =~ s{[\\]([\^\*\?])}{$1}g;
